@@ -1,4 +1,5 @@
-from flask import jsonify, Response
+from quart import Response, jsonify
+
 
 def json_resp(data, status):
-    return jsonify(data), status
\ No newline at end of file
+    return jsonify(data), status
